import React, { ReactNode } from 'react';
import { DefaultRules, Output, SingleASTNode, State } from 'simple-markdown';
import type { LocalMessage } from 'stream-chat';
import type { MessageContextValue } from '../../../../contexts/messageContext/MessageContext';
import type { Colors, MarkdownStyle } from '../../../../contexts/themeContext/utils/theme';
type ReactOutput = Output<React.ReactNode>;
export declare const MarkdownReactiveScrollView: ({ children }: {
    children: ReactNode;
}) => React.JSX.Element;
export type MarkdownRules = Partial<DefaultRules>;
export type RenderTextParams = Partial<Pick<MessageContextValue, 'onLongPress' | 'onPress' | 'preventPress'>> & {
    colors: typeof Colors;
    message: LocalMessage;
    markdownRules?: MarkdownRules;
    markdownStyles?: MarkdownStyle;
    messageOverlay?: boolean;
    messageTextNumberOfLines?: number;
    onLink?: (url: string) => Promise<void>;
    onlyEmojis?: boolean;
};
export declare const renderText: (params: RenderTextParams) => React.JSX.Element;
export interface ListOutputProps {
    node: SingleASTNode;
    output: ReactOutput;
    state: State;
    styles?: Partial<MarkdownStyle>;
}
/**
 * For lists and sublists, the default behavior of the markdown library we use is
 * to always renumber any list, so all ordered lists start from 1.
 *
 * This custom rule overrides this behavior both for top level lists and sublists,
 * in order to start the numbering from the number of the first list item provided.
 */
export declare const ListOutput: ({ node, output, state, styles }: ListOutputProps) => React.JSX.Element;
export type MarkdownTableProps = {
    node: SingleASTNode;
    output: ReactOutput;
    state: State;
    styles: Partial<MarkdownStyle>;
};
export type MarkdownTableRowProps = {
    items: SingleASTNode[];
    output: ReactOutput;
    state: State;
    styles: Partial<MarkdownStyle>;
};
export {};
//# sourceMappingURL=renderText.d.ts.map