import type { ColorValue, ImageStyle, TextStyle, ViewStyle } from 'react-native';
import type { CircleProps, StopProps } from 'react-native-svg';
import type { IconProps } from '../../../icons/utils/base';
export declare const DEFAULT_STATUS_ICON_SIZE = 16;
export declare const BASE_AVATAR_SIZE = 32;
export declare const Colors: {
    accent_blue: string;
    accent_dark_blue: string;
    accent_error: string;
    accent_green: string;
    accent_info: string;
    accent_red: string;
    bg_gradient_end: string;
    bg_gradient_start: string;
    bg_user: string;
    black: string;
    blue_alice: string;
    border: string;
    code_block: string;
    disabled: string;
    grey: string;
    grey_dark: string;
    grey_gainsboro: string;
    grey_whisper: string;
    icon_background: string;
    label_bg_transparent: string;
    light_blue: string;
    light_gray: string;
    modal_shadow: string;
    overlay: string;
    shadow_icon: string;
    static_black: string;
    static_white: string;
    targetedMessageBackground: string;
    text_high_emphasis: string;
    text_low_emphasis: string;
    transparent: string;
    white: string;
    white_smoke: string;
    white_snow: string;
};
export type MarkdownStyle = Partial<{
    autolink: TextStyle;
    blockQuoteBar: ViewStyle;
    blockQuoteSection: ViewStyle;
    blockQuoteSectionBar: ViewStyle;
    blockQuoteText: TextStyle | ViewStyle;
    br: TextStyle;
    codeBlock: TextStyle;
    del: TextStyle;
    em: TextStyle;
    heading: TextStyle;
    heading1: TextStyle;
    heading2: TextStyle;
    heading3: TextStyle;
    heading4: TextStyle;
    heading5: TextStyle;
    heading6: TextStyle;
    hr: ViewStyle;
    image: ImageStyle;
    inlineCode: TextStyle;
    list: ViewStyle;
    listItem: ViewStyle;
    listItemBullet: TextStyle;
    listItemNumber: TextStyle;
    listItemText: TextStyle;
    listRow: ViewStyle;
    mailTo: TextStyle;
    mentions: TextStyle;
    newline: TextStyle;
    noMargin: TextStyle;
    paragraph: TextStyle;
    paragraphCenter: TextStyle;
    paragraphWithImage: ViewStyle;
    strong: TextStyle;
    sublist: ViewStyle;
    table: ViewStyle;
    tableHeader: ViewStyle;
    tableHeaderCell: TextStyle;
    tableRow: ViewStyle;
    tableRowCell: TextStyle;
    tableRowLast: ViewStyle;
    text: TextStyle;
    u: TextStyle;
    view: ViewStyle;
}>;
export type Theme = {
    aiTypingIndicatorView: {
        container: ViewStyle;
        text: TextStyle;
    };
    attachmentPicker: {
        bottomSheetContentContainer: ViewStyle;
        durationText: TextStyle;
        errorButtonText: TextStyle;
        errorContainer: ViewStyle;
        errorText: TextStyle;
        image: ViewStyle;
        imageOverlay: ViewStyle;
        imageOverlaySelectedComponent: {
            check: ViewStyle;
        };
    };
    attachmentSelectionBar: {
        container: ViewStyle;
        icon: ViewStyle;
    };
    audioAttachment: {
        container: ViewStyle;
        leftContainer: ViewStyle;
        playPauseButton: ViewStyle;
        progressControlContainer: ViewStyle;
        progressDurationText: TextStyle;
        rightContainer: ViewStyle;
        speedChangeButton: ViewStyle;
        speedChangeButtonText: TextStyle;
    };
    avatar: {
        BASE_AVATAR_SIZE: number;
        container: ViewStyle;
        image: ImageStyle;
        presenceIndicator: CircleProps;
        presenceIndicatorContainer: ViewStyle;
    };
    bottomSheetModal: {
        container: ViewStyle;
        contentContainer: ViewStyle;
        handle: ViewStyle;
        overlay: ViewStyle;
        wrapper: ViewStyle;
    };
    channel: {
        selectChannel: TextStyle;
    };
    channelListFooterLoadingIndicator: {
        container: ViewStyle;
    };
    channelListHeaderErrorIndicator: {
        container: ViewStyle;
        errorText: TextStyle;
    };
    channelListLoadingIndicator: {
        container: ViewStyle;
    };
    channelListMessenger: {
        flatList: ViewStyle;
        flatListContent: ViewStyle;
    };
    channelListSkeleton: {
        animationTime: number;
        background: ViewStyle;
        container: ViewStyle;
        gradientStart: StopProps;
        gradientStop: StopProps;
        height: number;
        maskFillColor?: ColorValue;
    };
    channelPreview: {
        avatar: {
            size: number;
        };
        checkAllIcon: IconProps;
        checkIcon: IconProps;
        container: ViewStyle;
        contentContainer: ViewStyle;
        date: TextStyle;
        message: TextStyle & {
            fontWeight: TextStyle['fontWeight'];
        };
        mutedStatus: {
            height: number;
            iconStyle: ViewStyle;
            width: number;
        };
        row: ViewStyle;
        title: TextStyle;
        unreadContainer: ViewStyle;
        unreadText: TextStyle;
    };
    colors: typeof Colors & {
        [key: string]: string;
    };
    dateHeader: {
        container: ViewStyle;
        text: TextStyle;
    };
    emptyStateIndicator: {
        channelContainer: ViewStyle;
        channelDetails: TextStyle;
        channelTitle: TextStyle;
        messageContainer: ViewStyle;
        messageTitle: TextStyle;
    };
    groupAvatar: {
        container: ViewStyle;
        image: ImageStyle;
    };
    iconBadge: {
        icon: ViewStyle;
        iconInner: ViewStyle;
        unreadCount: TextStyle;
    };
    iconSquare: {
        container: ViewStyle;
        image: ImageStyle;
    };
    imageGallery: {
        footer: {
            centerContainer: ViewStyle;
            container: ViewStyle;
            imageCountText: TextStyle;
            innerContainer: ViewStyle;
            leftContainer: ViewStyle;
            rightContainer: ViewStyle;
        };
        grid: {
            container: ViewStyle;
            contentContainer: ViewStyle;
            gridAvatar: ImageStyle;
            gridAvatarWrapper: ViewStyle;
            gridImage: ViewStyle;
            handle: ViewStyle;
            handleText: TextStyle;
            overlay: ViewStyle;
        };
        header: {
            centerContainer: ViewStyle;
            container: ViewStyle;
            dateText: TextStyle;
            innerContainer: ViewStyle;
            leftContainer: ViewStyle;
            rightContainer: ViewStyle;
            usernameText: TextStyle;
        };
        videoControl: {
            durationTextStyle: TextStyle;
            progressDurationText: TextStyle;
            roundedView: ViewStyle;
            videoContainer: ViewStyle;
        };
        backgroundColor?: string;
        pager?: ViewStyle;
        slide?: ImageStyle;
    };
    inlineDateSeparator: {
        container: ViewStyle;
        text: TextStyle;
    };
    loadingDots: {
        container: ViewStyle;
        loadingDot: ViewStyle;
        spacing: number;
    };
    loadingErrorIndicator: {
        container: ViewStyle;
        errorText: TextStyle;
        retryText: TextStyle;
    };
    loadingIndicator: {
        container: ViewStyle;
        loadingText: TextStyle;
    };
    messageInput: {
        attachButton: ViewStyle;
        attachButtonContainer: ViewStyle;
        attachmentSelectionBar: ViewStyle;
        attachmentSeparator: ViewStyle;
        audioRecorder: {
            arrowLeftIcon: IconProps;
            checkContainer: ViewStyle;
            circleStopIcon: IconProps;
            deleteContainer: ViewStyle;
            deleteIcon: IconProps;
            micContainer: ViewStyle;
            micIcon: IconProps;
            pausedContainer: ViewStyle;
            sendCheckIcon: IconProps;
            slideToCancelContainer: ViewStyle;
        };
        audioRecordingButton: {
            container: ViewStyle;
            micIcon: IconProps;
        };
        audioRecordingInProgress: {
            container: ViewStyle;
            durationText: TextStyle;
        };
        audioRecordingLockIndicator: {
            arrowUpIcon: IconProps;
            container: ViewStyle;
            lockIcon: IconProps;
        };
        audioRecordingPreview: {
            container: ViewStyle;
            currentTime: TextStyle;
            infoContainer: ViewStyle;
            pauseIcon: IconProps;
            playIcon: IconProps;
            progressBar: ViewStyle;
        };
        audioRecordingWaveform: {
            container: ViewStyle;
            waveform: ViewStyle;
        };
        autoCompleteInputContainer: ViewStyle;
        commandsButton: ViewStyle;
        commandsButtonContainer: ViewStyle;
        composerContainer: ViewStyle;
        container: ViewStyle;
        cooldownTimer: {
            container: ViewStyle;
            text: TextStyle;
        };
        editingBoxContainer: ViewStyle;
        editingBoxHeader: ViewStyle;
        editingBoxHeaderTitle: TextStyle;
        editingStateHeader: {
            editingBoxHeader: ViewStyle;
            editingBoxHeaderTitle: TextStyle;
        };
        fileUploadPreview: {
            dismiss: ViewStyle;
            fileContainer: ViewStyle;
            filenameText: TextStyle;
            fileSizeText: TextStyle;
            fileTextContainer: ViewStyle;
            flatList: ViewStyle;
        };
        focusedInputBoxContainer: ViewStyle;
        giphyCommandInput: {
            giphyContainer: ViewStyle;
            giphyText: TextStyle;
        };
        imageUploadPreview: {
            dismiss: ViewStyle;
            dismissIconColor: ColorValue;
            flatList: ViewStyle;
            itemContainer: ViewStyle;
            upload: ImageStyle;
        };
        inputBox: TextStyle;
        inputBoxContainer: ViewStyle;
        micButtonContainer: ViewStyle;
        moreOptionsButton: ViewStyle;
        nativeAttachmentPicker: {
            buttonContainer: ViewStyle;
            buttonDimmerStyle: ViewStyle;
            container: ViewStyle;
        };
        optionsContainer: ViewStyle;
        replyContainer: ViewStyle;
        searchIcon: IconProps;
        sendButton: ViewStyle;
        sendButtonContainer: ViewStyle;
        sendMessageDisallowedIndicator: {
            container: ViewStyle;
            text: TextStyle;
        };
        sendRightIcon: IconProps;
        sendUpIcon: IconProps;
        showThreadMessageInChannelButton: {
            check: IconProps;
            checkBoxActive: ViewStyle;
            checkBoxInactive: ViewStyle;
            container: ViewStyle;
            innerContainer: ViewStyle;
            text: TextStyle;
        };
        stopMessageStreamingButton: ViewStyle;
        stopMessageStreamingIcon: IconProps;
        suggestions: {
            command: {
                args: TextStyle;
                container: ViewStyle;
                iconContainer: ViewStyle;
                title: TextStyle;
            };
            emoji: {
                container: ViewStyle;
                text: TextStyle;
            };
            header: {
                container: ViewStyle;
                title: TextStyle;
            };
            item: ViewStyle;
            mention: {
                avatarSize: number;
                column: ViewStyle;
                container: ViewStyle;
                name: TextStyle;
                tag: TextStyle;
            };
        };
        suggestionsListContainer: {
            container: ViewStyle;
            flatlist: ViewStyle;
        };
        uploadProgressIndicator: {
            container: ViewStyle;
            indicatorColor: string;
            overlay: ViewStyle;
        };
    };
    messageList: {
        container: ViewStyle;
        contentContainer: ViewStyle;
        errorNotification: ViewStyle;
        errorNotificationText: TextStyle;
        inlineUnreadIndicator: {
            container: ViewStyle;
            text: TextStyle;
        };
        listContainer: ViewStyle;
        messageContainer: ViewStyle;
        messageSystem: {
            container: ViewStyle;
            dateText: TextStyle;
            line: ViewStyle;
            text: TextStyle;
            textContainer: ViewStyle;
        };
        scrollToBottomButton: {
            container: ViewStyle;
            touchable: ViewStyle;
            unreadCountNotificationContainer: ViewStyle;
            unreadCountNotificationText: TextStyle;
            wrapper: ViewStyle;
            chevronColor?: ColorValue;
        };
        typingIndicatorContainer: ViewStyle;
        unreadMessagesNotification: {
            closeButtonContainer: ViewStyle;
            closeIcon: IconProps;
            container: ViewStyle;
            text: TextStyle;
        };
    };
    messageMenu: {
        actionList: {
            container: ViewStyle;
            contentContainer: ViewStyle;
        };
        actionListItem: {
            container: ViewStyle;
            icon: ViewStyle;
            title: TextStyle;
        };
        bottomSheet: {
            height?: number;
        };
        reactionButton: {
            filledColor: ColorValue;
            unfilledColor: ColorValue;
        };
        reactionPicker: {
            buttonContainer: ViewStyle;
            container: ViewStyle;
            contentContainer: ViewStyle;
            reactionIconSize: number;
        };
        userReactions: {
            avatarContainer: ViewStyle;
            avatarInnerContainer: ViewStyle;
            avatarName: TextStyle;
            avatarNameContainer: ViewStyle;
            avatarSize: number;
            container: ViewStyle;
            contentContainer: ViewStyle;
            flatlistColumnContainer: ViewStyle;
            flatlistContainer: ViewStyle;
            radius: number;
            reactionBubble: ViewStyle;
            reactionBubbleBackground: ViewStyle;
            reactionBubbleBorderRadius: number;
            reactionSelectorContainer: ViewStyle;
            reactionsText: TextStyle;
            title: TextStyle;
        };
    };
    messageSimple: {
        actions: {
            button: ViewStyle & {
                defaultBackgroundColor?: ViewStyle['backgroundColor'];
                defaultBorderColor?: ViewStyle['borderColor'];
                primaryBackgroundColor?: ViewStyle['backgroundColor'];
                primaryBorderColor?: ViewStyle['borderColor'];
            };
            buttonText: TextStyle & {
                defaultColor?: TextStyle['color'];
                primaryColor?: TextStyle['color'];
            };
            container: ViewStyle;
        };
        avatarWrapper: {
            container: ViewStyle;
            leftAlign: ViewStyle;
            rightAlign: ViewStyle;
            spacer: ViewStyle;
        };
        card: {
            authorName: TextStyle;
            authorNameContainer: ViewStyle;
            authorNameFooter: TextStyle;
            authorNameFooterContainer: ViewStyle;
            authorNameMask: ViewStyle;
            container: ViewStyle;
            cover: ImageStyle;
            footer: ViewStyle & {
                description: TextStyle;
                title: TextStyle;
            };
            noURI: ViewStyle;
            playButtonStyle: {
                durationTextStyle: TextStyle;
                roundedView: ViewStyle;
                videoContainer: ViewStyle;
            };
            playIcon: IconProps;
        };
        container: ViewStyle;
        content: {
            container: ViewStyle & {
                borderRadiusL: ViewStyle['borderBottomLeftRadius' | 'borderTopLeftRadius'];
                borderRadiusS: ViewStyle['borderBottomRightRadius' | 'borderTopRightRadius'];
            };
            containerInner: ViewStyle;
            deletedContainer: ViewStyle;
            deletedContainerInner: ViewStyle;
            deletedMetaText: TextStyle;
            deletedText: MarkdownStyle;
            editedLabel: TextStyle;
            editedTimestampContainer: ViewStyle;
            errorContainer: ViewStyle;
            errorIcon: IconProps;
            errorIconContainer: ViewStyle;
            eyeIcon: IconProps;
            lastMessageContainer: ViewStyle;
            /**
             * Available options for styling text:
             * https://github.com/andangrd/react-native-markdown-package/blob/main/styles.js
             */
            markdown: MarkdownStyle;
            messageGroupedSingleOrBottomContainer: ViewStyle;
            messageGroupedTopContainer: ViewStyle;
            messageUser: TextStyle;
            metaContainer: ViewStyle;
            metaText: TextStyle;
            replyBorder: ViewStyle;
            replyContainer: ViewStyle;
            textContainer: ViewStyle & {
                onlyEmojiMarkdown: MarkdownStyle;
            };
            wrapper: ViewStyle;
            receiverMessageBackgroundColor?: ColorValue;
            senderMessageBackgroundColor?: ColorValue;
            timestampText?: TextStyle;
        };
        contentWrapper: ViewStyle;
        file: {
            container: ViewStyle;
            details: ViewStyle;
            fileSize: TextStyle;
            icon: IconProps;
            title: TextStyle;
        };
        fileAttachmentGroup: {
            attachmentContainer: ViewStyle;
            container: ViewStyle;
        };
        gallery: {
            galleryContainer: ViewStyle;
            galleryItemColumn: ViewStyle;
            gridHeight: number;
            gridWidth: number;
            image: ImageStyle;
            imageContainer: ViewStyle;
            imageContainerStyle: ViewStyle;
            maxHeight: number;
            maxWidth: number;
            minHeight: number;
            minWidth: number;
            moreImagesContainer: ViewStyle;
            moreImagesText: TextStyle;
            thumbnail: ViewStyle;
            imageBorderRadius?: {
                borderBottomLeftRadius: number;
                borderBottomRightRadius: number;
                borderTopLeftRadius: number;
                borderTopRightRadius: number;
            };
        };
        giphy: {
            buttonContainer: ViewStyle;
            cancel: TextStyle;
            container: ViewStyle;
            giphy: ImageStyle;
            giphyContainer: ViewStyle;
            giphyHeaderText: TextStyle;
            giphyHeaderTitle: TextStyle;
            giphyMask: ViewStyle;
            giphyMaskText: TextStyle;
            header: ViewStyle;
            selectionContainer: ViewStyle;
            send: TextStyle;
            shuffle: TextStyle;
            title: TextStyle;
        };
        headerWrapper: ViewStyle;
        lastMessageContainer: ViewStyle;
        loadingIndicator: {
            container: ViewStyle;
            roundedView: ViewStyle;
        };
        messageGroupedSingleOrBottomContainer: ViewStyle;
        messageGroupedTopContainer: ViewStyle;
        pinnedHeader: {
            container: ViewStyle;
            label: TextStyle;
        };
        reactionListBottom: {
            contentContainer: ViewStyle;
            item: {
                container: ViewStyle;
                countText: TextStyle;
                icon: ViewStyle;
                iconFillColor: ColorValue;
                iconSize: number;
                iconUnFillColor: ColorValue;
            };
        };
        reactionListTop: {
            container: ViewStyle;
            item: {
                container: ViewStyle;
                icon: ViewStyle;
                iconFillColor: ColorValue;
                iconSize: number;
                iconUnFillColor: ColorValue;
                reactionSize: number;
            };
            position: number;
        };
        replies: {
            avatar: ViewStyle;
            avatarContainerMultiple: ViewStyle;
            avatarContainerSingle: ViewStyle;
            container: ViewStyle;
            leftAvatarsContainer: ViewStyle;
            leftCurve: ViewStyle;
            messageRepliesText: TextStyle;
            rightAvatarsContainer: ViewStyle;
            rightCurve: ViewStyle;
            avatarSize?: number;
        };
        status: {
            checkAllIcon: IconProps;
            checkIcon: IconProps;
            readByCount: TextStyle;
            statusContainer: ViewStyle;
            timeIcon: IconProps;
        };
        swipeContentContainer: ViewStyle;
        swipeLeftContent: {
            container: ViewStyle;
        };
        targetedMessageContainer: ViewStyle;
        videoThumbnail: {
            container: ViewStyle;
            roundedView: ViewStyle;
        };
        unreadUnderlayColor?: ColorValue;
        wrapper: ViewStyle;
    };
    poll: {
        allOptions: {
            listContainer: ViewStyle;
            titleContainer: ViewStyle;
            titleText: TextStyle;
            wrapper: ViewStyle;
        };
        answersList: {
            buttonContainer: ViewStyle;
            container: ViewStyle;
            item: {
                answerText: TextStyle;
                container: ViewStyle;
                infoContainer: ViewStyle;
                userInfoContainer: ViewStyle;
            };
        };
        button: {
            container: ViewStyle;
            text: TextStyle;
        };
        createContent: {
            addComment: {
                title: TextStyle;
                wrapper: ViewStyle;
            };
            anonymousPoll: {
                title: TextStyle;
                wrapper: ViewStyle;
            };
            headerContainer: ViewStyle;
            maxVotes: {
                input: TextStyle;
                validationText: TextStyle;
                wrapper: ViewStyle;
            };
            multipleAnswers: {
                row: ViewStyle;
                title: TextStyle;
                wrapper: ViewStyle;
            };
            name: {
                input: TextStyle;
                title: TextStyle;
            };
            pollOptions: {
                addOption: {
                    text: TextStyle;
                    wrapper: ViewStyle;
                };
                container: ViewStyle;
                optionStyle: {
                    input: TextStyle;
                    validationErrorText: TextStyle;
                    wrapper: ViewStyle;
                };
                title: TextStyle;
            };
            scrollView: ViewStyle;
            sendButton: ViewStyle;
            suggestOption: {
                title: TextStyle;
                wrapper: ViewStyle;
            };
        };
        fullResults: {
            container: ViewStyle;
            contentContainer: ViewStyle;
            headerContainer: ViewStyle;
            headerText: TextStyle;
        };
        inputDialog: {
            button: TextStyle;
            buttonContainer: ViewStyle;
            container: ViewStyle;
            input: TextStyle;
            title: TextStyle;
            transparentContainer: ViewStyle;
        };
        message: {
            container: ViewStyle;
            header: {
                subtitle: TextStyle;
                title: TextStyle;
            };
            option: {
                container: ViewStyle;
                progressBar: ViewStyle;
                progressBarEmptyFill: string;
                progressBarVotedFill: string;
                progressBarWinnerFill: string;
                text: TextStyle;
                voteButtonActive: string;
                voteButtonContainer: ViewStyle;
                voteButtonInactive: string;
                votesContainer: ViewStyle;
                wrapper: ViewStyle;
            };
            optionsWrapper: ViewStyle;
        };
        modalHeader: {
            container: ViewStyle;
            title: TextStyle;
        };
        results: {
            container: ViewStyle;
            item: {
                container: ViewStyle;
                headerContainer: ViewStyle;
                title: TextStyle;
                voteCount: TextStyle;
            };
            scrollView: ViewStyle;
            title: TextStyle;
            vote: {
                container: ViewStyle;
                dateText: TextStyle;
                userName: TextStyle;
            };
        };
    };
    progressControl: {
        container: ViewStyle;
        filledColor: ColorValue;
        filledStyles: ViewStyle;
        thumb: ViewStyle;
    };
    reply: {
        container: ViewStyle;
        fileAttachmentContainer: ViewStyle;
        imageAttachment: ImageStyle;
        markdownStyles: MarkdownStyle;
        messageContainer: ViewStyle;
        secondaryText: ViewStyle;
        textContainer: ViewStyle;
        videoThumbnail: {
            container: ViewStyle;
            image: ImageStyle;
        };
    };
    screenPadding: number;
    spinner: ViewStyle;
    thread: {
        newThread: ViewStyle & {
            text: TextStyle;
            backgroundGradientStart?: string;
            backgroundGradientStop?: string;
            threadHeight?: number;
        };
    };
    threadListItem: {
        boldText: TextStyle;
        contentRow: ViewStyle;
        contentTextWrapper: ViewStyle;
        dateText: TextStyle;
        headerRow: ViewStyle;
        infoRow: ViewStyle;
        lastReplyText: TextStyle;
        parentMessageText: TextStyle;
        touchableWrapper: ViewStyle;
        unreadBubbleText: TextStyle;
        unreadBubbleWrapper: ViewStyle;
    };
    threadListUnreadBanner: {
        text: TextStyle;
        touchableWrapper: ViewStyle;
    };
    typingIndicator: {
        container: ViewStyle;
        text: TextStyle & {
            fontSize: TextStyle['fontSize'];
        };
    };
    waveProgressBar: {
        container: ViewStyle;
        thumb: ViewStyle;
        waveform: ViewStyle;
    };
};
export declare const defaultTheme: Theme;
//# sourceMappingURL=theme.d.ts.map