import type { Attachment, Channel, LocalMessage, MessageResponse, UserResponse } from 'stream-chat';

import {
  GROUP_CHANNEL_MEMBERS_MOCK,
  ONE_MEMBER_WITH_EMPTY_USER_MOCK,
} from '../../mock-builders/api/queryMembers';

const channelName = 'okechukwu';
const CHANNEL = {
  data: { name: channelName },
  state: { messages: [] },
} as unknown as Channel;

const CHANNEL_WITH_MESSAGES_TEXT = {
  data: { name: channelName },
  state: {
    members: GROUP_CHANNEL_MEMBERS_MOCK,
    messages: [
      {
        args: 'string',
        attachments: [],
        channel: CHANNEL,
        cid: 'stridkncnng',
        command: 'giphy',
        command_info: { name: 'string' },
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        id: 'ljkblk',
        text: 'jkbkbiubicbi',
        type: 'MessageLabel',
        user: { id: 'okechukwu' } as unknown as UserResponse,
      } as unknown as MessageResponse,
      {
        args: 'string',
        attachments: [],
        channel: CHANNEL,
        cid: 'stridodong',
        command: 'giphy',
        command_info: { name: 'string' },
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        id: 'jbkjb',
        text: 'jkbkbiubicbi',
        type: 'MessageLabel',
        user: { id: 'okechukwu' } as unknown as UserResponse,
      } as unknown as MessageResponse,
    ],
  },
} as unknown as Channel;

const CHANNEL_WITH_DELETED_MESSAGES = {
  data: { name: channelName },
  state: {
    members: GROUP_CHANNEL_MEMBERS_MOCK,
    messages: [
      {
        type: 'deleted',
      } as unknown as MessageResponse,
      {
        type: 'deleted',
      } as unknown as MessageResponse,
    ],
  },
} as unknown as Channel;

const CHANNEL_WITH_NO_MESSAGES = {
  data: { name: channelName },
  state: {
    members: GROUP_CHANNEL_MEMBERS_MOCK,
    messages: [],
  },
} as unknown as Channel;

const CHANNEL_WITH_MESSAGE_COMMAND = {
  data: { name: channelName },
  state: {
    members: GROUP_CHANNEL_MEMBERS_MOCK,
    messages: [
      {
        args: 'string',
        attachments: [],
        channel: CHANNEL,
        cid: 'stridkncnng',
        command: 'giphy',
        command_info: { name: 'string' },
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        id: 'ljkblk',
        user: { id: 'okechukwu' } as unknown as UserResponse,
      } as unknown as MessageResponse,
      {
        args: 'string',
        attachments: [],
        channel: CHANNEL,
        cid: 'stridodong',
        command: 'giphy',
        command_info: { name: 'string' },
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        id: 'jbkjb',
        user: { id: 'okechukwu' } as unknown as UserResponse,
      } as unknown as MessageResponse,
    ],
  },
} as unknown as Channel;

const CHANNEL_WITH_MESSAGES_ATTACHMENTS = {
  data: { name: channelName },
  state: {
    members: GROUP_CHANNEL_MEMBERS_MOCK,
    messages: [
      {
        args: 'string',
        attachments: [
          {
            actions: [],
            asset_url: 'string',
            author_icon: 'string',
            author_link: 'string',
            author_name: 'string',
            color: 'string',
            fallback: 'string',
            fields: [],
            file_size: 25,
            footer: 'string',
            footer_icon: 'string',
            image_url: 'string',
            mime_type: 'string',
            og_scrape_url: 'string',
            original_height: 5,
            original_width: 4,
            pretext: 'string',
            text: 'string',
            thumb_url: 'string',
            title: 'string',
            title_link: 'string',
            type: 'string',
          } as Attachment,
        ],
        channel: CHANNEL,
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        id: 'ljkblk',
        user: { id: 'okechukwu' } as unknown as UserResponse,
      } as unknown as MessageResponse,
    ],
  },
} as unknown as Channel;

const LATEST_MESSAGE = {
  args: 'string',
  attachments: [],
  channel: CHANNEL,
  cid: 'string',
  command: 'giphy',
  command_info: { name: 'string' },
  created_at: new Date('2021-02-12T12:12:35.862Z'),
  deleted_at: new Date('2021-02-12T12:12:35.862Z'),
  id: 'string',
  text: 'jkbkbiubicbi',
  type: 'MessageLabel',
  user: { id: 'okechukwu' } as unknown as UserResponse,
} as unknown as MessageResponse;

const FORMATTED_MESSAGE: LocalMessage = {
  created_at: new Date('2021-02-12T12:12:35.862282Z'),
  id: '',
  message: {} as unknown as MessageResponse,
  pinned_at: new Date('2021-02-12T12:12:35.862282Z'),
  status: 'received',
  type: 'regular',
  updated_at: new Date('2021-02-12T12:12:35.862282Z'),
};

const CHANNEL_WITH_MENTIONED_USERS = {
  state: {
    members: ONE_MEMBER_WITH_EMPTY_USER_MOCK,
    messages: [
      {
        args: 'string',
        attachments: [],
        cid: 'stridkncnng',
        command_info: { name: 'string' },
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        mentioned_users: [
          { id: 'Max', name: 'Max' },
          { id: 'Ada', name: 'Ada' },
          { id: 'Enzo', name: 'Enzo' },
        ] as UserResponse[],
        text: 'Max',
      } as unknown as MessageResponse,
      {
        args: 'string',
        attachments: [],
        cid: 'stridodong',
        command_info: { name: 'string' },
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        mentioned_users: [
          { id: 'Max', name: 'Max' },
          { id: 'Ada', name: 'Ada' },
          { id: 'Enzo', name: 'Enzo' },
        ] as UserResponse[],
        text: 'Max',
      } as unknown as MessageResponse,
    ],
  },
} as unknown as Channel;

const CHANNEL_WITH_EMPTY_MESSAGE = {
  state: {
    members: ONE_MEMBER_WITH_EMPTY_USER_MOCK,
    messages: [
      {
        args: 'string',
        attachments: [],
        cid: 'stridkncnng',
        command_info: { name: 'string' },
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        mentioned_users: [
          { id: 'Max', name: 'Max' },
          { id: 'Ada', name: 'Ada' },
          { id: 'Enzo', name: 'Enzo' },
        ] as UserResponse[],
      } as unknown as MessageResponse,
      {
        args: 'string',
        attachments: [],
        cid: 'stridodong',
        command_info: { name: 'string' },
        created_at: new Date('2021-02-12T12:12:35.862Z'),
        deleted_at: new Date('2021-02-12T12:12:35.862Z'),
        mentioned_users: [
          { id: 'Max', name: 'Max' },
          { id: 'Ada', name: 'Ada' },
          { id: 'Enzo', name: 'Enzo' },
        ] as UserResponse[],
      } as unknown as MessageResponse,
    ],
  },
} as unknown as Channel;

const CHANNEL_WITH_MESSAGES = {
  data: { name: channelName },
  state: {
    members: GROUP_CHANNEL_MEMBERS_MOCK,
    messages: [FORMATTED_MESSAGE, FORMATTED_MESSAGE],
  },
} as unknown as Channel;

export {
  CHANNEL,
  CHANNEL_WITH_EMPTY_MESSAGE,
  CHANNEL_WITH_MESSAGES,
  CHANNEL_WITH_MENTIONED_USERS,
  FORMATTED_MESSAGE,
  LATEST_MESSAGE,
  CHANNEL_WITH_MESSAGES_ATTACHMENTS,
  CHANNEL_WITH_MESSAGE_COMMAND as CHANNEL_WITH_MESSAGES_COMMAND,
  CHANNEL_WITH_NO_MESSAGES,
  CHANNEL_WITH_DELETED_MESSAGES,
  CHANNEL_WITH_MESSAGES_TEXT,
};
